#!/usr/bin/env python

"""Get data script"""
__author__ = "Filip Maly"
__copyright__ = "Copyright 2018 Filip Maly"

__license__ = "GPL"
__version__ = "1.2"
__maintainer__ = "Filip Maly"
__email__ = "filipmaly92@gmail.com"
__status__ = "Development"


#from MultiWii import MultiWii
from Multiwii2 import MultiWii
from sys import stdout

from Config import Config

import httplib, urllib
import json
import datetime
import time
import pygame
import requests
import json
import picamera
import base64

class Telemetry:
    def __init__(self):
        self.config = Config()
        self.board =  MultiWii(self.config.getSerialPort())
        #self.initializateCamera()

        self.connection = httplib.HTTPSConnection(self.config.getHost())
        self.photoConn = httplib.HTTPSConnection(self.config.getHost())

        print 'Nastaven port: ' + str(self.config.getFromMetadata('serailPort')) + ', a baudRate: ' + str(self.config.getFromMetadata('baudRate'))

        pygame.init()
        pygame.mixer.music.load("sound.mp3")
        pygame.mixer.music.set_volume(1)

        self.startProgram()

    def initializateCamera(self):
        try:
            self.camera = picamera.PiCamera()
            self.camera.capture('image.jpg')
            self.camera.hflip = True
            self.camera.vflip = True
        except Exception, error:
            print "Kamera neni inicializovana: " + str(error)

    def startProgram(self):
        counter = 1
        try:
            while True:
                self.sendTelemetry(self.getTelemetryData(), self.config.getDeviceUrl(), self.config.getTelemetryHeader())
                self.getResponse()
                time.sleep(self.config.getFromMetadata('timeSleep'))
                print counter
                counter = counter + 1
        except Exception, error:
            print "Chyba v cyklu programu " + str(error)

    def getResponse(self):
        response = requests.get('https://' + self.config.getHost() + self.config.getDeviceUrl(), headers=self.config.getRequestHeader())
        #print 'test odpovedi:' + str(response.status_code)

        if response.status_code == 200:
            data = json.loads(response.text)
            for x in range(0, len(data)):
                print data[x]
                messageData = data[x]['messages']
                if (messageData[0]['commandID'] == 1):
                    # ALARM ON
                    print messageData[0]['commandID']
                    pygame.mixer.music.play()
                elif (messageData[0]['commandID'] == 2):
                    # ALARM OFF
                    pygame.mixer.music.stop()
                    print messageData[0]['commandID']
                elif (messageData[0]['commandID'] == 3):
                    # TAKE PHOTO
                    #elf.takePhoto()
                    print messageData[0]['commandID']
                elif (messageData[0]['commandID'] == 4):
                    # LED ON
                    print messageData[0]['commandID']
                elif (messageData[0]['commandID'] == 5):
                    # LED OFF
                    print messageData[0]['commandID']
                elif (messageData[0]['commandID'] == 6):
                    # GpS_HOLD ON
                    print messageData[0]['commandID']
                elif (messageData[0]['commandID'] == 7):
                    # GpS_HOLD OFF
                    print messageData[0]['commandID']
                elif (messageData[0]['commandID'] == 8):
                    #GPS_HOME ON
                    print messageData[0]['commandID']
                elif (messageData[0]['commandID'] == 9):
                    # GPS_HOME OFF
                    print messageData[0]['commandID']

    def takePhoto(self):
        try:
            self.camera.capture('image.jpg')
            image = 'image.jpg'
            image_64 = base64.encodestring(open(image, "rb").read())
            photoString = "data:image/png;base64," + image_64
            self.sendPhoto(photoString)
        except Exception, error:
            print "Error on Photo " + str(error)

    def getTelemetryData(self):
        RC = self.board.getData(MultiWii.RC)
        GPS =  self.board.getData(MultiWii.RAW_GPS)
        MOTORS =  self.board.getData(MultiWii.MOTOR)
        ATTITUDE =  self.board.getData(MultiWii.ALTITUDE)
        DISTANCEHOME =  self.board.getData(MultiWii.COMP_GPS)
        print GPS
        # ANOLOG = board.getAnalog()
        # IDENT = board.getIdent()
        body = {
            'mode': 'sync',
            #'messageType': idMessage,
            'messages': [{
                # 'aux1': RC['aux1'],
                # 'aux2': RC['aux2'],
                # 'aux3': RC['aux3'],
                # 'aux4': RC['aux4'],
                'fix': GPS['fix'],
                'numsat': GPS['numsat'],
                'longitude': GPS['longitude'],
                'latitude': GPS['latitude'],
                'speed': GPS['speed'],
                'altitude': GPS['altitude'],
                # 'distanceHome': DISTANCEHOME['distance'],
                # 'headingHome': DISTANCEHOME['heading'],
                # 'amperage': ANOLOG['amperage'],
                # 'rssi': ANOLOG['rssi'],
                # 'vbat': ANOLOG['vbat'],
                # 'powermetersum': ANOLOG['powermetersum'],
                # 'version': IDENT['version'],
                # 'type': IDENT['type'],
                # 'angx': ATTITUDE['angx'],
                # 'angy': ATTITUDE['angy'],
                # 'heading': ATTITUDE['heading']
            }]
        }

        body = self.config.getTelemetryBody()

        body['messages'][0]['roll'] = RC['roll']
        body['messages'][0]['throttle'] = RC['throttle']
        body['messages'][0]['yaw'] = RC['yaw']
        body['messages'][0]['pitch'] = RC['pitch']

        body['messages'][0]['motor1'] = MOTORS['m1'],
        body['messages'][0]['motor2'] = MOTORS['m2'],
        body['messages'][0]['motor3'] = MOTORS['m6'],
        body['messages'][0]['motor4'] = MOTORS['m4'],
        body['messages'][0]['motor5'] = MOTORS['m5'],
        body['messages'][0]['motor6'] = MOTORS['m6'],
        body['messages'][0]['motor7'] = MOTORS['m7'],
        body['messages'][0]['motor8'] = MOTORS['m8'],

        return body

    def sendPhoto(self , photo):
        bodyPhoto = self.config.getBodyPhoto()
        bodyPhoto['messages'][0]['photoBase64'] = photo,
        self.photoConn.request("POST", self.config.getDeviceUrl(), json.dumps(bodyPhoto), self.config.getPhotoHeader())
        r2 = self.photoConn.getresponse()
        print r2.status, r2.reason
        self.photoConn.close()


    def sendTelemetry(self , body, url, header):
        self.connection.request("POST", url, json.dumps(body), header)
        r1 = self.connection.getresponse()
        print r1.status, r1.reason
        print body
        self.connection.close()

# spusteni main a kodu

def main():
    classTelemetry = Telemetry()
    classTelemetry.__init__()

if __name__ == "__main__":
    main()