/*global sap */

sap.ui.define([
	'sap/ui/core/ValueState',
	'sap/m/MessageBox'
], function(ValueState, MessageBox) {
	"use strict";

	var Validator = function() {};

	Validator.prototype.validateForm = function(oForm) {
		var bValid = true;
		oForm.getFormContainers().forEach(function(oContainer) {
			oContainer.getFormElements().forEach(function(oFormElement) {
				if (oFormElement.getLabel().getRequired && oFormElement.getLabel().getRequired()) {
					oFormElement.getFields().forEach(function(oControl) {
						if (!this.validateControl(oControl)) {
							bValid = false;
						}

					}.bind(this));
				}
			}.bind(this));
		}.bind(this));
		return bValid;
	};

	Validator.prototype.validateTableInput = function(oTable) {
		var bValid = true;
		oTable.getItems().forEach(function(oRow) {
			oRow.getCells().forEach(function(oCell) {
				if (oCell.getMetadata()._sClassName === "sap.m.Input") {
					if (!this.validateControl(oCell)) {
						bValid = false;
					}
				}

			}.bind(this));
		}.bind(this));
		return bValid;
	};

	Validator.prototype.validateControl = function(oControl) {
		var bValid = true;
		var bControlState = true;
		var sClass = oControl.getMetadata()._sClassName;
		switch (sClass) {
			case "sap.m.Input":
				var sName = oControl.getName();
				if (sName === "EMAIL") {
					var regEx =
						/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
					bValid = oControl.getValue().search(regEx) === 0;
				} else {
					bValid = oControl.getValue() !== "";
				}
				break;
			case "sap.m.ComboBox":
			case "sap.m.Select":
				//bValid = oControl.getSelectedKey() !== "";
				bValid = oControl.getSelectedItem() !== null;
				break;
			case "sap.m.MultiComboBox":
				bValid = oControl.getSelectedKeys().length > 0;
				break;
			case "sap.m.DatePicker":
				bValid = oControl.getDateValue() instanceof Date && oControl.getDateValue() !== null;
				break;
			default:
				bControlState = false;
				bValid = true;
				break;
		}

		//EXTRA FOR NON-STATE CONTROLS 
		if (bControlState && oControl.setValueState) {
			oControl.setValueState(bValid ? ValueState.None : ValueState.Error);
		}

		return bValid;
	};

	return Validator;
});