sap.ui.define([
	"sap/ui/core/mvc/ViewType",
	"sap/ui/Device",
	"sap/m/SplitAppMode"
], function(ViewType, Device, SplitAppMode) {
	"use strict";

	sap.ui.jsview("DRONEDRONE_IOT.view.master", {

		/** Specifies the Controller belonging to this View. 
		 * In the case that it is not implemented, or that "null" is returned, this View does not have a Controller.
		 * @memberOf controller.master
		 */
		getControllerName: function() {
			return "DRONEDRONE_IOT.controller.master";
		},

		/** Is initially called once after the Controller has been instantiated. It is the place where the UI is constructed. 
		 * Since the Controller is given to this method, its event handlers can be attached right away.
		 * @memberOf controller.master
		 */
		createContent: function(oController) {

			var oPage = new sap.m.SplitApp({
				id: this.createId("splitApp"),
				//mode: "ShowHideMode",

				mode: "HideMode",
				masterPages: [
					new sap.m.semantic.MasterPage({
						busy: true,
						title: "{i18n>titleMaster}",
						id: this.createId("masterPage"),
						showNavButton: Device.system.phone,
						navButtonPress: [oController.toMainPage, oController],
						showFooter: true,
						content: [
							new sap.ui.xmlfragment("DRONEDRONE_IOT.fragment.masterPage", oController)
						],
						customHeaderContent: [
							new sap.m.Button({
								enabled: true,
								icon: "sap-icon://add",
								press: [oController.onAddNewModel, oController]
							})
						],

						customFooterContent: [
							new sap.m.Button({
								icon: "sap-icon://edit",
								press: [oController.onEditMaster, oController],
								visible: "{= ${mainModel>/enableEdit}  === false }"
							}),
							new sap.m.Button({
								icon: "sap-icon://delete",
								press: [oController.onMasterPageDelete, oController],
								visible: "{mainModel>/enableEdit}",
								type: "Reject"
							}),
							new sap.m.Button({
								icon: "sap-icon://save",
								press: [oController.onMasterPageUpdateDrone, oController],
								visible: "{mainModel>/enableEdit}",
								type: "Accept"
							}),
							new sap.m.Button({
								icon: "sap-icon://undo",
								press: [oController.onShowMaster, oController],
								visible: "{mainModel>/enableEdit}"
							})
						]
					})
				],
				detailPages: [
					new sap.m.semantic.DetailPage({
						id: this.createId("mainPage"),
						title: "{i18n>mainPageTitle}",
						showNavButton: Device.system.phone,
						navButtonPress: [oController.onToMaster, oController],
						content: [
							new sap.m.IconTabBar({
								selectedKey: "{mainModel>/tabKey}",
								expandable: false,
								id: this.createId("iconTabBar"),
								applyContentPadding: false,
								select: [oController.onPresIconTab, oController],
								items: [
									new sap.m.IconTabFilter({
										key: "monitoring",
										icon: "sap-icon://map-2",
										text: "{i18n>iconAppMonitoring}",
										tooltip: "{i18n>iconAppMonitoring}",
										content: [new sap.ui.xmlfragment("DRONEDRONE_IOT.fragment.monitoringToolbar", oController),
											new sap.ui.jsfragment("DRONEDRONE_IOT.fragment.monitoring", oController)
										]
									}),
									new sap.m.IconTabFilter({
										key: "request",
										icon: "sap-icon://wrench",
										text: "{i18n>iconAppRequest}",
										tooltip: "{i18n>iconAppRequest}",
										content: [new sap.ui.xmlfragment("DRONEDRONE_IOT.fragment.request", oController)]
									}),
									new sap.m.IconTabFilter({
										key: "photo",
										icon: "sap-icon://picture",
										text: "{i18n>iconAppPhoto}",
										tooltip: "{i18n>iconAppPhoto}",
										content: [new sap.ui.xmlfragment("DRONEDRONE_IOT.fragment.photo", oController)]
									}),

									new sap.m.IconTabFilter({
										key: "database",
										icon: "sap-icon://database",
										text: "{i18n>iconAppLogTable}",
										tooltip: "{i18n>iconAppLogTable}",
										content: [new sap.ui.xmlfragment("DRONEDRONE_IOT.fragment.tableLog", oController)]
									}),

									// TO DO: V DP práci nebude

									new sap.m.IconTabFilter({
										key: "mission",
										icon: "sap-icon://paper-plane",
										text: "{i18n>iconAppMission}",
										tooltip: "{i18n>iconAppMission}",
										visible: false,
										content: [
											new sap.ui.xmlfragment("DRONEDRONE_IOT.fragment.missionToolbar", oController)
										]
									}),

									new sap.m.IconTabFilter({
										key: "about",
										icon: "sap-icon://puzzle",
										iconColor: "Positive",
										text: "{i18n>iconAbout}",
										tooltip: "{i18n>iconAbout}",
										content: [new sap.ui.xmlfragment("DRONEDRONE_IOT.fragment.about", oController)]
									})
								]

							})
						],
						customHeaderContent: [
							new sap.m.ObjectStatus({
								enabled: true,
								text: {
									path: 'mainModel>/isRefreshOn',
									formatter: oController.headerInfoText
								},
								state: {
									path: 'mainModel>/isRefreshOn',
									formatter: oController.headerInfoState
								},
								icon: {
									path: 'mainModel>/isRefreshOn',
									formatter: oController.headerInfoIcon
								}
							}).addStyleClass("sapUiSmallMarginEnd"),
							new sap.m.Label({
								enabled: true,
								text: "{i18n>selectedDrone}: {mainModel>/selectedDrone}",
								design: "Bold",
								icon: "sap-icon://alert"
							})
						],

						customFooterContent: [
							new sap.m.Toolbar({
								width: '100%',
								content: [
									new sap.m.Button({
										icon: "sap-icon://alert",
										type: 'Emphasized',
										visible: {
											path: 'mainModel>/visibleErrBtn'
										},
										text: {
											path: 'mainModel>/countErrBtn'
										},
										press: [oController.onMessagesButtonPress, oController]
									}),

									new sap.m.ToolbarSpacer({}),

									new sap.m.Button({
										icon: "sap-icon://map-3",
										visible: {
											path: 'mainModel>/btnFootMap'
										},
										press: [oController.tableCreateRoute, oController]
									})
								]

							})

						]

					}),

					new sap.m.semantic.DetailPage({
						id: this.createId("noDataPage"),
						title: "{i18n>noDataPageTitle}",
						content: [
							new sap.m.FlexBox({
								height: "100%",
								width: "100%",
								alignItems: "Center",
								justifyContent: "Center",
								items: [
									new sap.m.Text({
										text: "{i18n>noDataPageText}"
									})
								]
							})

						],
						customFooterContent: []

					})

				]

			});

			var app = new sap.m.App("myApp", {
				initialPage: "oPage"
			});
			app.addPage(oPage);
			return app;
		}
	});
});